@@ -68,13 +68,9 @@
 #'
 #' @name predictRTConf
 #' @importFrom stats integrate
-#' @import dplyr
 #' @importFrom progress progress_bar
-#' @importFrom magrittr %>%
-#' @importFrom rlang .data
 # @importFrom pracma integral
 #' @aliases predictConf
-#' @importFrom Rcpp evalCpp
 #'
 #' @examples
 #' # Examples for "dynWEV" model (equivalent applicable for
@@ -138,9 +134,9 @@ predictConf <- function(paramDf, model=NULL,
   #### Check model argument
   if (grepl("RM", model)) {
     res <- predictRM_Conf(paramDf, model, FALSE, maxrt, subdivisions, stop.on.error, .progress)
-  } else if (model %in% c("dynWEV", "2DSD")) {
+  } else if (grepl("dynWEV|2DSD|dynaViTE", model)) {
     res <- predictWEV_Conf(paramDf, model, maxrt, subdivisions,simult_conf, stop.on.error, .progress=.progress)
-  } else if (model == "DDMConf") {
+  } else if (grepl("DDMConf", model)) {
     res <- predictDDMConf_Conf(paramDf,  maxrt, subdivisions, stop.on.error, .progress)
   } else { stop("model not known.")}
   return(res)
@@ -162,9 +158,9 @@ predictRT <- function(paramDf, model=NULL,
   #### Check model argument
   if (grepl("RM", model)) {
     res <- predictRM_RT(paramDf, model, FALSE, maxrt, subdivisions, minrt, scaled, DistConf, .progress)
-  } else if (model %in% c("dynWEV","2DSD")) {
+  } else if (grepl("dynWEV|2DSD|dynaViTE", model)) {
     res <- predictWEV_RT(paramDf, model, maxrt, subdivisions, minrt, simult_conf, scaled, DistConf, .progress=.progress)
-  } else if (model == "DDMConf") {
+  } else if (grepl("DDMConf", model)) {
     res <- predictDDMConf_RT(paramDf, maxrt, subdivisions,  minrt, scaled, DistConf, .progress)
   } else { stop("model not known.")}
   return(res)
