@@ -23,115 +23,113 @@ using namespace Rcpp;
 
 // Forward declarations
 
-double g_minus_WEVmu (double t);
-double g_plus_WEVmu  (double t);
+double g_minus_WEVmu (double t, NumericVector params);
 
-static double integral_t0_g_minus_WEVmu (double t, Parameters *params);
-static double integral_z_g_minus_WEVmu  (double t, Parameters *params);
-static double integral_v_g_minus_WEVmu  (double t, double zr, Parameters *params);
+static double integral_t0_g_minus_WEVmu (double t, NumericVector params);
+static double integral_z_g_minus_WEVmu  (double t, NumericVector params);
+static double integral_v_g_minus_WEVmu  (double t, double zr, NumericVector params);
 
 static double g_minus_small_time_WEVmu (double t, double zr, int N);
 static double g_minus_large_time_WEVmu (double t, double zr, int N);
 
 // TODO: Make sure these function names are accurate
-static double integrate_z_over_t_WEVmu  (Parameters *params, double a, double b, double step_width);
-static double integrate_v_over_zr_WEVmu (Parameters *params, double a, double b, double t, double step_width);
+static double integrate_z_over_t_WEVmu  (NumericVector params, double a, double b, double step_width);
+static double integrate_v_over_zr_WEVmu (NumericVector params, double a, double b, double t, double step_width);
 
 
 // Main calls
-NumericVector density_WEVmu (NumericVector rts, int boundary, int stopon0)
+NumericVector density_WEVmu (NumericVector rts, NumericVector params, int boundary, int stopon0)
 {
     int length = rts.length();
     NumericVector out(length);
     if (stopon0 == 1) {
       if (boundary == 1) {
+        params[7] = 1- params[7]; // z -> 1 - z
+        params[1] = - params[1]; // v  -> - v
+        params[3] = - params[3]; // d  -> - d
         for (int i = 0; i < length; i++) {
-          out[i] =  g_plus_WEVmu(rts[i]);
+          out[i] =  g_minus_WEVmu(rts[i], params);
           if (out[i]==0) break;
         }
       } // Calc upper
       else {
         for (int i = 0; i < length; i++) {
-          out[i] = -g_minus_WEVmu(rts[i]);
+          out[i] = -g_minus_WEVmu(rts[i], params);
           if (out[i]==0) break;
         }
       } // Calc lower
     } else {
-      if (boundary == 1) { for (int i = 0; i < length; i++) { out[i] =  g_plus_WEVmu(rts[i]); } } // Calc upper
-      else { for (int i = 0; i < length; i++) { out[i] = -g_minus_WEVmu(rts[i]); } } // Calc lower
+      if (boundary == 1) {
+        params[7] = 1- params[7]; // z -> 1 - z
+        params[1] = - params[1]; // v  -> - v
+        params[3] = - params[3]; // d  -> - d
+        for (int i = 0; i < length; i++) {
+          out[i] =  g_minus_WEVmu(rts[i], params);
+          }
+        } // Calc upper
+      else { for (int i = 0; i < length; i++) { out[i] = -g_minus_WEVmu(rts[i], params); } } // Calc lower
     }
     return out;
 }
 
-double g_minus_WEVmu(double t)
+double g_minus_WEVmu(double t, NumericVector params)
 {
-    return integral_t0_g_minus_WEVmu (t - g_Params->t0 - 0.5*g_Params->d, g_Params);
-}
-
-double g_plus_WEVmu(double t)
-{
-    // Make a copy so we don't disturb our params
-    // (?TODO: we could optimise the object creation out and just set them back after the call)
-    Parameters new_params(*g_Params);
-    new_params.zr = 1 - g_Params->zr;
-    new_params.v = -g_Params->v;
-
-    return integral_t0_g_minus_WEVmu (t - new_params.t0 + 0.5*new_params.d, &new_params);
+    return integral_t0_g_minus_WEVmu (t - params[2] - 0.5*params[3], params);
 }
 
 
 
-static double integral_t0_g_minus_WEVmu (double t, Parameters *params)
+static double integral_t0_g_minus_WEVmu (double t, NumericVector params)
 {
     double res;
 
-    if (params->st0 < params->TUNE_ST0_EPSILON) // 170501   was == 0)
+    if (params[6] < params[19]) // 170501   was == 0)
     {
         res = integral_z_g_minus_WEVmu (t, params);
     }
     else
     {
         res = integrate_z_over_t_WEVmu(params,
-                        t - .5*params->st0,
-                        t + .5*params->st0, params->TUNE_INT_T0) / params->st0;
+                                       t - .5*params[6],
+                                       t + .5*params[6], params[16]) / params[6];
     }
 
     return res;
 }
 
 
-static double integral_z_g_minus_WEVmu (double t, Parameters *params)
+static double integral_z_g_minus_WEVmu (double t, NumericVector params)
 {
     double res;
 
     if (t <= 0) return 0;
 
-    if (params->szr < params->TUNE_SZ_EPSILON)
+    if (params[4] < params[18])
     {
-        res = integral_v_g_minus_WEVmu (t, params->zr, params);
+        res = integral_v_g_minus_WEVmu (t, params[7], params);
     }
     else
     {
-        res = integrate_v_over_zr_WEVmu(params, params->zr - .5*params->szr, params->zr + .5*params->szr,
-                                  t, params->TUNE_INT_Z) / params->szr;
+        res = integrate_v_over_zr_WEVmu(params, params[7] - .5*params[4], params[7] + .5*params[4],
+                                        t, params[17]) / params[4];
     }
     return res;
 }
 
 
-static double integral_v_g_minus_WEVmu (double t, double zr, Parameters *params)
+static double integral_v_g_minus_WEVmu (double t, double zr, NumericVector params)
 {
-    double a = params->a;
-    double v = params->v;
-    double sv = params->sv;
-    double tau = params->tau;
-    double th2 = params->th2;
-    double th1 = params->th1;
-    double muvis = params->muvis;
-    double svis2 = params->svis*params->svis;
-    double sigvis2 = params->sigvis*params->sigvis;
-    double w = params->w;
-    double omega = params->omega;
+  double a = params[0];
+  double v = params[1];
+  double sv = params[5];
+  double tau = params[8];
+  double th1 = params[9];
+  double th2 = params[10];
+  double lambda = params[11];
+  double w = params[12];
+  double muvis = params[13];
+  double sigvis2 = params[14]*params[14];
+  double svis2 = params[15]*params[15];
 
 
 
@@ -152,9 +150,9 @@ static double integral_v_g_minus_WEVmu (double t, double zr, Parameters *params)
     ttau = t+tau;
     Mu = (ttau*(1-w)*muvis - w*(tau*v-a*zr*(sv*sv*ttau+1))/(sv2t)) ;
     Sigma = sqrt(( w*w*tau* (1+ tau*sv*sv/sv2t) + (1-w)*(1-w)*(ttau*svis2 + ttau*ttau*sigvis2)));
-    if (omega > 0)
+    if (lambda > 0)
     {
-      int_c = Phi((th2*pow(ttau, omega)-Mu)/Sigma) - Phi((th1*pow(ttau, omega)-Mu)/Sigma);
+      int_c = Phi((th2*pow(ttau, lambda)-Mu)/Sigma) - Phi((th1*pow(ttau, lambda)-Mu)/Sigma);
     }
     else
     {
@@ -226,7 +224,7 @@ static double g_minus_large_time_WEVmu(double t, double zr, int N)
 
 // CONVERSION NOTE: Simplest way to deal with the integrate function is to remove
 //                  the clever recursiveness and instead (ugh) duplicate code
-static double integrate_z_over_t_WEVmu (Parameters *params, double a, double b, double step_width)
+static double integrate_z_over_t_WEVmu (NumericVector params, double a, double b, double step_width)
 {
     double width = b-a;
     int N = std::max(4, (int) (width / step_width));
@@ -241,7 +239,7 @@ static double integrate_z_over_t_WEVmu (Parameters *params, double a, double b,
     return result;
 }
 
-static double integrate_v_over_zr_WEVmu (Parameters *params, double a, double b, double t, double step_width)
+static double integrate_v_over_zr_WEVmu (NumericVector params, double a, double b, double t, double step_width)
 {
     double width = b-a;
     int N = std::max(4, (int) (width / step_width));
