@@ -25,7 +25,6 @@
 
 using namespace Rcpp;
 
-
 // R-callable PDF for 2DSD - pass boundary to retrieve (1 = lower, 2 = upper)
 // [[Rcpp::export]]
 NumericVector d_2DSD (NumericVector rts, NumericVector params, double precision=1e-5, int boundary=2, bool stop_on_error=true, int stop_on_zero=false)
@@ -35,19 +34,26 @@ NumericVector d_2DSD (NumericVector rts, NumericVector params, double precision=
 
     if ((boundary < 1) || (boundary > 2)) { Rcpp::stop ("Boundary must be either 2 (upper) or 1 (lower)\n"); }
 
-    g_Params = new Parameters (params, precision);
-
     NumericVector out(length, 0.0);  // Should default to 0s when creating NumericVector, but just in case..
 
-    if (!g_Params->ValidateParams_2DSD(stop_on_error))
+    if (!ValidateParams(params, true))
     {
         if (stop_on_error) { Rcpp::stop("Error validating parameters.\n"); }
                       else { return out; }
     }
 
-    out = density_2DSD (rts, boundary-1, stop_on_zero);
+    // Add tuning values for numerical integrations at the end of parameters
+    // ToDo: Optimize and check precision values
+    params.push_back(0.0089045 * exp(-1.037580*precision)); // TUNE_INT_T0
+    params.push_back(0.0508061 * exp(-1.022373*precision)); // TUNE_INT_Z
+    //     These have been added to optimise code paths by treating very small variances as 0
+    //     e.g. with precision = 3, sv or sz values < 10^-5 are considered 0
+    params.push_back(pow (10, -(precision+2.0))); // TUNE_SZ_EPSILON
+    params.push_back(pow (10, -(precision+2.0))); // TUNE_ST0_EPSILON
 
-    delete g_Params;
+    out = density_2DSD (rts, params, boundary-1, stop_on_zero);
+
+    //delete g_Params;
     return out;
 }
 
@@ -61,22 +67,62 @@ NumericVector d_WEVmu (NumericVector rts, NumericVector params, double precision
 
     if ((boundary < 1) || (boundary > 2)) { Rcpp::stop ("Boundary must be either 2 (upper) or 1 (lower)\n"); }
 
-    g_Params = new Parameters (params, precision);
-
     NumericVector out(length, 0.0);  // Should default to 0s when creating NumericVector, but just in case..
 
-    if (!g_Params->ValidateParams_2DSD(stop_on_error))
+    if (!ValidateParams(params, true))
     {
-        if (stop_on_error) { Rcpp::stop("Error validating parameters.\n"); }
-        else { return out; }
+      if (stop_on_error) { Rcpp::stop("Error validating parameters.\n"); }
+      else { return out; }
     }
 
-    out = density_WEVmu (rts, boundary-1, stop_on_zero);
+    // Add tuning values for numerical integrations at the end of parameters
+    // ToDo: Optimize and check precision values
+    params.push_back(0.0089045 * exp(-1.037580*precision)); // TUNE_INT_T0
+    params.push_back(0.0508061 * exp(-1.022373*precision)); // TUNE_INT_Z
+    //     These have been added to optimise code paths by treating very small variances as 0
+    //     e.g. with precision = 3, sv or sz values < 10^-5 are considered 0
+    params.push_back(pow (10, -(precision+2.0))); // TUNE_SZ_EPSILON
+    params.push_back(pow (10, -(precision+2.0))); // TUNE_ST0_EPSILON
+
+    out = density_WEVmu (rts, params, boundary-1, stop_on_zero);
 
-    delete g_Params;
     return out;
 }
 
+// R-callable PDF for DDMConf - pass boundary to retrieve (1 = lower, 2 = upper)
+// [[Rcpp::export]]
+NumericVector d_DDMConf (NumericVector rts, NumericVector params, double precision=1e-5, int boundary=2,
+                         bool stop_on_error=true, bool stop_on_zero=false,
+                         double st0precision=0.01)
+{
+  int length = rts.length();
+  if (length > MAX_INPUT_VALUES) { Rcpp::stop("Number of RT values passed in exceeds maximum of %d.\n", MAX_INPUT_VALUES); }
+
+  if ((boundary < 1) || (boundary > 2)) { Rcpp::stop ("Boundary must be either 2 (upper) or 1 (lower)\n"); }
+
+
+  NumericVector out(length, 0.0);  // Should default to 0s when creating NumericVector, but just in case..
+
+  if (!ValidateParams(params, true))
+  {
+    if (stop_on_error) { Rcpp::stop("Error validating parameters.\n"); }
+    else { return out; }
+  }
+
+  // Add tuning values for numerical integrations at the end of parameters
+  // ToDo: Optimize and check precision values
+  params.push_back(0.0089045 * exp(-1.037580*precision)); // TUNE_INT_T0
+  params.push_back(0.0508061 * exp(-1.022373*precision)); // TUNE_INT_Z
+  //     These have been added to optimise code paths by treating very small variances as 0
+  //     e.g. with precision = 3, sv or sz values < 10^-5 are considered 0
+  params.push_back(pow (10, -(precision+2.0))); // TUNE_SZ_EPSILON
+  params.push_back(pow (10, -(precision+2.0))); // TUNE_ST0_EPSILON
+
+  out = density_DDMConf (rts, params, boundary-1, stop_on_zero, st0precision);
+
+  return out;
+}
+
 // [[Rcpp::export]]
 NumericVector d_IRM (NumericVector rts, NumericVector params, int win=1,  double step_width = 0.0001)
 {
@@ -102,7 +148,7 @@ NumericVector d_IRM2 (NumericVector rts, NumericVector params, int win=1,  doubl
 
   NumericVector out(length, 0.0);  // Should default to 0s when creating NumericVector, but just in case..
 
-  out = density_IRM (rts, params, win, step_width);
+  out = density_IRM2 (rts, params, win, step_width);
 
   return out;
 }
@@ -307,19 +353,10 @@ NumericVector dd_PCRM (NumericVector rts, NumericVector xj, NumericVector params
 // [[Rcpp::export]]
 NumericVector r_RM (int n, NumericVector params, double rho, double delta=0.01, double maxT=9)
 {
-  double sdu, sdv, muu, muv, noise1, noise2;
-  if (params[6] !=0 ) {
-    noise1 = R::rnorm(0, params[6]);
-  } else {
-    noise1 = 0;
-  }
-  if (params[7] !=0 ) {
-    noise2 = R::rnorm(0, params[7]);
-  } else {
-    noise2 = 0;
-  }
-  muu = (params[0]+params[1])*delta;
-  muv = (params[0]-params[1])*delta;
+  double sdu, sdv, driftnoise1, driftnoise2; //muu, muv,
+
+  // muu = (params[0]+params[1])*delta;
+  // muv = (params[0]-params[1])*delta;
 
   sdu = sqrt(2*(1+rho)*delta);
   sdv = sqrt(2*(1-rho)*delta);
@@ -329,14 +366,24 @@ NumericVector r_RM (int n, NumericVector params, double rho, double delta=0.01,
 
   NumericMatrix out(n, 3);
   for (int i=0; i < n; i++) {
+    if (params[6] !=0 ) {
+      driftnoise1 = R::rnorm(0, params[6]);
+    } else {
+      driftnoise1 = 0;
+    }
+    if (params[7] !=0 ) {
+      driftnoise2 = R::rnorm(0, params[7]);
+    } else {
+      driftnoise2 = 0;
+    }
     x01 = params[2]+R::runif(0, params[8]);
     x02 = params[3]+R::runif(0, params[9]);
     t = 0;
     while ((x01 < 0) && (x02 < 0) && (t < maxT)) {
       u = R::rnorm(0, sdu);
       v = R::rnorm(0, sdv);
-      x01 = x01 + delta*noise1 + 0.5*((muu+muv)+params[4]*(u+v));
-      x02 = x02 + delta*noise2 + 0.5*((muu-muv)+params[5]*(u-v));
+      x01 = x01 + delta*(driftnoise1 + params[0]) + 0.5*params[4]*(u+v);
+      x02 = x02 + delta*(driftnoise2 + params[1]) + 0.5*params[5]*(u-v);
       t += delta;
     }
     if (x01 > 0) {
@@ -371,31 +418,14 @@ NumericVector r_RM (int n, NumericVector params, double rho, double delta=0.01,
 
 
 // [[Rcpp::export]]
-NumericMatrix r_WEV (int n, NumericVector params, int model,
+NumericMatrix r_WEV (int n, NumericVector params,
                      double delta=0.01, double maxT=9,
                      bool stop_on_error=true)
 {
-  g_Params = new Parameters (params, 1e-3);
-
-  NumericMatrix out(n, 3);
-
-  if (!g_Params->ValidateParams_2DSD(stop_on_error))
-  {
-    if (stop_on_error) { Rcpp::stop("Error validating parameters.\n"); }
-    else { return out;  }
-  }
-
-  // model codes: 1: 2DSD, 2: dynWEV
-  if (model == 1) {
-      params[12] = 1; // w
-      params[13] = 0; // muvis (arbitrary value)
-      params[14] = 1; // sigvis(arbitrary value)
-      params[15] = 1; // svis  (arbitrary value)
-  }
-
+  if (params.length()<13) { Rcpp::stop("Not enough parameters supplied.\n"); }
+  NumericMatrix out(n, 6);
   out = RNG_WEV(n,  params, delta, maxT, stop_on_error);
 
-  delete g_Params;
   return out;
 }
 
@@ -606,37 +636,6 @@ NumericVector r_LCA (int n, NumericVector params, double delta=0.01, double maxT
 
 
 
-// R-callable PDF for DDMConf - pass boundary to retrieve (1 = lower, 2 = upper)
-// [[Rcpp::export]]
-NumericVector d_DDMConf (NumericVector rts, NumericVector params, double precision=1e-5, int boundary=2,
-                         bool stop_on_error=true, bool stop_on_zero=false,
-                         double st0precision=0.01)
-{
-  int length = rts.length();
-  if (length > MAX_INPUT_VALUES) { Rcpp::stop("Number of RT values passed in exceeds maximum of %d.\n", MAX_INPUT_VALUES); }
-
-  if ((boundary < 1) || (boundary > 2)) { Rcpp::stop ("Boundary must be either 2 (upper) or 1 (lower)\n"); }
-
-  g_Params = new Parameters (params, precision);
-
-  NumericVector out(length, 0.0);  // Should default to 0s when creating NumericVector, but just in case..
-
-  if (!g_Params->ValidateParams_2DSD(stop_on_error))
-  {
-    if (stop_on_error) { Rcpp::stop("Error validating parameters.\n"); }
-    else { return out; }
-  }
-
-  out = density_DDMConf (rts, boundary-1, stop_on_zero, st0precision);
-
-  delete g_Params;
-  return out;
-}
-
-
-
-
-
 // [[Rcpp::export]]
 NumericVector r_DDMConf (int n, NumericVector params, double delta=0.01, double maxT=9, bool stop_on_error=true)
 {
